@@ -1,6 +1,6 @@
 // This module implements the QsciLexerPerl class.
 //
-// Copyright (c) 2008 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2012 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of QScintilla.
 // 
@@ -16,18 +16,8 @@
 // GPL Exception version 1.1, which can be found in the file
 // GPL_EXCEPTION.txt in this package.
 // 
-// Please review the following information to ensure GNU General
-// Public Licensing requirements will be met:
-// http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-// you are unsure which license is appropriate for your use, please
-// review the following information:
-// http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-// or contact the sales department at sales@riverbankcomputing.com.
-// 
-// This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-// INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-// granted herein.
+// If you are unsure which license is appropriate for your use, please
+// contact the sales department at sales@riverbankcomputing.com.
 // 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -43,8 +33,8 @@
 // The ctor.
 QsciLexerPerl::QsciLexerPerl(QObject *parent, const char *name)
     : QsciLexer(parent, name),
-      fold_comments(false), fold_compact(true), fold_packages(true),
-      fold_pod_blocks(true)
+      fold_atelse(false), fold_comments(false), fold_compact(true),
+      fold_packages(true), fold_pod_blocks(true)
 {
 }
 
@@ -142,6 +132,7 @@ QColor QsciLexerPerl::defaultColor(int style) const
     case QuotedStringQR:
     case QuotedStringQW:
     case SubroutinePrototype:
+    case Translation:
         return QColor(0x00,0x00,0x00);
 
     case DataSection:
@@ -150,6 +141,17 @@ QColor QsciLexerPerl::defaultColor(int style) const
     case FormatIdentifier:
     case FormatBody:
         return QColor(0xc0,0x00,0xc0);
+
+    case DoubleQuotedStringVar:
+    case RegexVar:
+    case SubstitutionVar:
+    case BackticksVar:
+    case DoubleQuotedHereDocumentVar:
+    case BacktickHereDocumentVar:
+    case QuotedStringQQVar:
+    case QuotedStringQXVar:
+    case QuotedStringQRVar:
+        return QColor(0xd0, 0x00, 0x00);
     }
 
     return QsciLexer::defaultColor(style);
@@ -168,6 +170,8 @@ bool QsciLexerPerl::defaultEolFill(int style) const
     case BacktickHereDocument:
     case PODVerbatim:
     case FormatBody:
+    case DoubleQuotedHereDocumentVar:
+    case BacktickHereDocumentVar:
         return true;
     }
 
@@ -185,6 +189,8 @@ QFont QsciLexerPerl::defaultFont(int style) const
     case Comment:
 #if defined(Q_OS_WIN)
         f = QFont("Comic Sans MS",9);
+#elif defined(Q_OS_MAC)
+        f = QFont("Comic Sans MS", 12);
 #else
         f = QFont("Bitstream Vera Serif",9);
 #endif
@@ -193,6 +199,8 @@ QFont QsciLexerPerl::defaultFont(int style) const
     case POD:
 #if defined(Q_OS_WIN)
         f = QFont("Times New Roman",11);
+#elif defined(Q_OS_MAC)
+        f = QFont("Times New Roman", 12);
 #else
         f = QFont("Bitstream Charter",10);
 #endif
@@ -202,6 +210,13 @@ QFont QsciLexerPerl::defaultFont(int style) const
     case Operator:
     case DoubleQuotedHereDocument:
     case FormatIdentifier:
+    case RegexVar:
+    case SubstitutionVar:
+    case BackticksVar:
+    case DoubleQuotedHereDocumentVar:
+    case BacktickHereDocumentVar:
+    case QuotedStringQXVar:
+    case QuotedStringQRVar:
         f = QsciLexer::defaultFont(style);
         f.setBold(true);
         break;
@@ -212,6 +227,8 @@ QFont QsciLexerPerl::defaultFont(int style) const
     case PODVerbatim:
 #if defined(Q_OS_WIN)
         f = QFont("Courier New",10);
+#elif defined(Q_OS_MAC)
+        f = QFont("Courier", 12);
 #else
         f = QFont("Bitstream Vera Sans Mono",9);
 #endif
@@ -223,6 +240,18 @@ QFont QsciLexerPerl::defaultFont(int style) const
         f.setItalic(true);
         break;
 
+    case DoubleQuotedStringVar:
+    case QuotedStringQQVar:
+#if defined(Q_OS_WIN)
+        f = QFont("Courier New",10);
+#elif defined(Q_OS_MAC)
+        f = QFont("Courier", 12);
+#else
+        f = QFont("Bitstream Vera Sans Mono",9);
+#endif
+        f.setBold(true);
+        break;
+
     default:
         f = QsciLexer::defaultFont(style);
     }
@@ -372,6 +401,36 @@ QString QsciLexerPerl::description(int style) const
 
     case FormatBody:
         return tr("Format body");
+
+    case DoubleQuotedStringVar:
+        return tr("Double-quoted string (interpolated variable)");
+
+    case Translation:
+        return tr("Translation");
+
+    case RegexVar:
+        return tr("Regular expression (interpolated variable)");
+
+    case SubstitutionVar:
+        return tr("Substitution (interpolated variable)");
+
+    case BackticksVar:
+        return tr("Backticks (interpolated variable)");
+
+    case DoubleQuotedHereDocumentVar:
+        return tr("Double-quoted here document (interpolated variable)");
+
+    case BacktickHereDocumentVar:
+        return tr("Backtick here document (interpolated variable)");
+
+    case QuotedStringQQVar:
+        return tr("Quoted string (qq, interpolated variable)");
+
+    case QuotedStringQXVar:
+        return tr("Quoted string (qx, interpolated variable)");
+
+    case QuotedStringQRVar:
+        return tr("Quoted string (qr, interpolated variable)");
     }
 
     return QString();
@@ -405,9 +464,12 @@ QColor QsciLexerPerl::defaultPaper(int style) const
         return QColor(0xa0,0xff,0xa0);
 
     case Substitution:
+    case Translation:
         return QColor(0xf0,0xe0,0x80);
 
     case Backticks:
+    case BackticksVar:
+    case QuotedStringQXVar:
         return QColor(0xa0,0x80,0x80);
 
     case DataSection:
@@ -417,6 +479,8 @@ QColor QsciLexerPerl::defaultPaper(int style) const
     case SingleQuotedHereDocument:
     case DoubleQuotedHereDocument:
     case BacktickHereDocument:
+    case DoubleQuotedHereDocumentVar:
+    case BacktickHereDocumentVar:
         return QColor(0xdd,0xd0,0xdd);
 
     case PODVerbatim:
@@ -433,6 +497,7 @@ QColor QsciLexerPerl::defaultPaper(int style) const
 // Refresh all properties.
 void QsciLexerPerl::refreshProperties()
 {
+    setAtElseProp();
     setCommentProp();
     setCompactProp();
     setPackagesProp();
@@ -447,6 +512,13 @@ bool QsciLexerPerl::readProperties(QSettings &qs,const QString &prefix)
 
     bool ok, flag;
 
+    flag = qs.readBoolEntry(prefix + "foldatelse", false, &ok);
+
+    if (ok)
+        fold_atelse = flag;
+    else
+        rc = false;
+
     flag = qs.readBoolEntry(prefix + "foldcomments", false, &ok);
 
     if (ok)
@@ -484,6 +556,9 @@ bool QsciLexerPerl::writeProperties(QSettings &qs,const QString &prefix) const
 {
     int rc = true;
 
+    if (!qs.writeEntry(prefix + "foldatelse", fold_atelse))
+        rc = false;
+
     if (!qs.writeEntry(prefix + "foldcomments", fold_comments))
         rc = false;
 
@@ -590,3 +665,19 @@ void QsciLexerPerl::setPODBlocksProp()
 {
     emit propertyChanged("fold.perl.pod",(fold_pod_blocks ? "1" : "0"));
 }
+
+
+// Set if else can be folded.
+void QsciLexerPerl::setFoldAtElse(bool fold)
+{
+    fold_atelse = fold;
+
+    setAtElseProp();
+}
+
+
+// Set the "fold.perl.at.else" property.
+void QsciLexerPerl::setAtElseProp()
+{
+    emit propertyChanged("fold.perl.at.else",(fold_atelse ? "1" : "0"));
+}
