@@ -1,6 +1,6 @@
 // This module implements the "official" low-level API.
 //
-// Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2012 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of QScintilla.
 // 
@@ -100,7 +100,11 @@ QsciScintillaBase::QsciScintillaBase(QWidget *parent, const char *name,
 
     setFocusPolicy(WheelFocus);
 
-    sci = new ScintillaQt(this);
+#if QT_VERSION >= 0x040200 && defined(Q_OS_MAC)
+    RectangularPasteboardMime::initialise();
+#endif
+
+    sci = new QsciScintillaQt(this);
 
     SendScintilla(SCI_SETCARETPERIOD, QApplication::cursorFlashTime() / 2);
 
@@ -298,7 +302,7 @@ long QsciScintillaBase::SendScintilla(unsigned int msg, int wParam) const
 long QsciScintillaBase::SendScintilla(unsigned int msg, long cpMin, long cpMax,
         char *lpstrText) const
 {
-    TextRange tr;
+    QSCI_SCI_NAMESPACE(TextRange) tr;
 
     tr.chrg.cpMin = cpMin;
     tr.chrg.cpMax = cpMax;
@@ -332,9 +336,9 @@ long QsciScintillaBase::SendScintilla(unsigned int msg, const QColor &col) const
 long QsciScintillaBase::SendScintilla(unsigned int msg, unsigned long wParam,
         QPainter *hdc, const QRect &rc, long cpMin, long cpMax) const
 {
-    RangeToFormat rf;
+    QSCI_SCI_NAMESPACE(RangeToFormat) rf;
 
-    rf.hdc = rf.hdcTarget = reinterpret_cast<SurfaceID>(hdc);
+    rf.hdc = rf.hdcTarget = reinterpret_cast<QSCI_SCI_NAMESPACE(SurfaceID)>(hdc);
 
     rf.rc.left = rc.left();
     rf.rc.top = rc.top();
@@ -373,7 +377,7 @@ void *QsciScintillaBase::SendScintillaPtrResult(unsigned int msg) const
 }
 
 
-// Handle the timer on behalf of the ScintillaQt instance.
+// Handle the timer on behalf of the QsciScintillaQt instance.
 void QsciScintillaBase::handleTimer()
 {
     sci->Tick();
@@ -383,7 +387,7 @@ void QsciScintillaBase::handleTimer()
 // Re-implemented to handle the context menu.
 void QsciScintillaBase::contextMenuEvent(QContextMenuEvent *e)
 {
-    sci->ContextMenu(Point(e->globalX(), e->globalY()));
+    sci->ContextMenu(QSCI_SCI_NAMESPACE(Point)(e->globalX(), e->globalY()));
 }
 
 
@@ -577,13 +581,14 @@ void QsciScintillaBase::mouseDoubleClickEvent(QMouseEvent *e)
     setFocus();
 
     // Make sure Scintilla will interpret this as a double-click.
-    unsigned clickTime = sci->lastClickTime + Platform::DoubleClickTime() - 1;
+    unsigned clickTime = sci->lastClickTime + QSCI_SCI_NAMESPACE(Platform)::DoubleClickTime() - 1;
 
     bool shift = e->state() & Qt::ShiftButton;
     bool ctrl = e->state() & Qt::ControlButton;
     bool alt = e->state() & Qt::AltButton;
 
-    sci->ButtonDown(Point(e->x(), e->y()), clickTime, shift, ctrl, alt);
+    sci->ButtonDown(QSCI_SCI_NAMESPACE(Point)(e->x(), e->y()), clickTime,
+            shift, ctrl, alt);
 
     // Remember the current position and time in case it turns into a triple
     // click.
@@ -595,7 +600,7 @@ void QsciScintillaBase::mouseDoubleClickEvent(QMouseEvent *e)
 // Handle a mouse move.
 void QsciScintillaBase::mouseMoveEvent(QMouseEvent *e)
 {
-    sci->ButtonMove(Point(e->x(), e->y()));
+    sci->ButtonMove(QSCI_SCI_NAMESPACE(Point)(e->x(), e->y()));
 }
 
 
@@ -604,7 +609,7 @@ void QsciScintillaBase::mousePressEvent(QMouseEvent *e)
 {
     setFocus();
 
-    Point pt(e->x(), e->y());
+    QSCI_SCI_NAMESPACE(Point) pt(e->x(), e->y());
 
     if (e->button() == Qt::LeftButton)
     {
@@ -613,9 +618,9 @@ void QsciScintillaBase::mousePressEvent(QMouseEvent *e)
         // It is a triple click if the timer is running and the mouse hasn't
         // moved too much.
         if (triple_click.isActive() && (e->globalPos() - triple_click_at).manhattanLength() < QApplication::startDragDistance())
-            clickTime = sci->lastClickTime + Platform::DoubleClickTime() - 1;
+            clickTime = sci->lastClickTime + QSCI_SCI_NAMESPACE(Platform)::DoubleClickTime() - 1;
         else
-            clickTime = sci->lastClickTime + Platform::DoubleClickTime() + 1;
+            clickTime = sci->lastClickTime + QSCI_SCI_NAMESPACE(Platform)::DoubleClickTime() + 1;
 
         triple_click.stop();
 
@@ -643,7 +648,9 @@ void QsciScintillaBase::mousePressEvent(QMouseEvent *e)
         {
             int pos = sci->PositionFromLocation(pt);
 
+            sci->sel.Clear();
             sci->SetSelection(pos, pos);
+
             sci->pasteFromClipboard(QClipboard::Selection);
         }
     }
@@ -657,7 +664,7 @@ void QsciScintillaBase::mouseReleaseEvent(QMouseEvent *e)
     {
         bool ctrl = e->state() & Qt::ControlButton;
 
-        sci->ButtonUp(Point(e->x(), e->y()), 0, ctrl);
+        sci->ButtonUp(QSCI_SCI_NAMESPACE(Point)(e->x(), e->y()), 0, ctrl);
     }
 }
 
@@ -700,7 +707,7 @@ void QsciScintillaBase::dragEnterEvent(QDragEnterEvent *e)
 // Handle drag leaves.
 void QsciScintillaBase::dragLeaveEvent(QDragLeaveEvent *)
 {
-    sci->SetDragPosition(SelectionPosition());
+    sci->SetDragPosition(QSCI_SCI_NAMESPACE(SelectionPosition)());
 }
 
 
@@ -708,7 +715,8 @@ void QsciScintillaBase::dragLeaveEvent(QDragLeaveEvent *)
 void QsciScintillaBase::dragMoveEvent(QDragMoveEvent *e)
 {
     sci->SetDragPosition(
-            sci->SPositionFromLocation(Point(e->pos().x(), e->pos().y()),
+            sci->SPositionFromLocation(
+                    QSCI_SCI_NAMESPACE(Point)(e->pos().x(), e->pos().y()),
                     false, false, sci->UserVirtualSpace()));
 
     if (sci->pdoc->IsReadOnly() || !QTextDrag::canDecode(e))
@@ -725,6 +733,7 @@ void QsciScintillaBase::dragMoveEvent(QDragMoveEvent *e)
 void QsciScintillaBase::dropEvent(QDropEvent *e)
 {
     bool moving;
+    int len;
     const char *s;
     bool rectangular;
 
@@ -740,21 +749,30 @@ void QsciScintillaBase::dropEvent(QDropEvent *e)
 
     e->acceptAction();
 
-    QCString cs;
+    QCString bytes;
 
     if (sci->IsUnicodeMode())
     {
-        cs = text.utf8();
-        s = cs.data();
+        bytes = text.utf8();
+
+        len = bytes.length();
+        s = bytes.data();
     }
     else
     {
         s = text.latin1();
+        len = (s ? qstrlen(s) : 0);
     }
 
     rectangular = false;
 
+    s = QSCI_SCI_NAMESPACE(Document)::TransformLineEnds(&len, s, len,
+                sci->pdoc->eolMode);
+
     sci->DropAt(sci->posDrop, s, moving, rectangular);
+
+    delete[] s;
+
     sci->Redraw();
 }
 
